==> offhandhotbar-1.0.4%2Bmc1.21.8-sources.jar: archives/tater/offhandhotbar/mixin/client/MouseMixin.java <==
package archives.tater.offhandhotbar.mixin.client;

import archives.tater.offhandhotbar.OffhandHotbar;
import archives.tater.offhandhotbar.OffhandHotbarConfig;
import com.llamalad7.mixinextras.injector.ModifyExpressionValue;
import com.llamalad7.mixinextras.injector.wrapoperation.Operation;
import com.llamalad7.mixinextras.injector.wrapoperation.WrapOperation;
import net.minecraft.class_1268;
import net.minecraft.class_1661;
import net.minecraft.class_310;
import net.minecraft.class_312;
import org.spongepowered.asm.mixin.Final;
import org.spongepowered.asm.mixin.Mixin;
import org.spongepowered.asm.mixin.Shadow;
import org.spongepowered.asm.mixin.injection.At;
import org.spongepowered.asm.mixin.injection.Inject;
import org.spongepowered.asm.mixin.injection.callback.CallbackInfo;

@Mixin(class_312.class)
public class MouseMixin {
    @Shadow @Final
    private class_310 client;

    @Inject(
            method = "onMouseScroll",
            at = @At(value = "INVOKE", target = "Lnet/minecraft/client/network/ClientPlayerEntity;getInventory()Lnet/minecraft/entity/player/PlayerInventory;"),
            cancellable = true
    )
    private void scrollInventory(long window, double horizontal, double vertical, CallbackInfo ci) {
        if (client.field_1755 != null) return;
        if (!OffhandHotbar.SCROLL_INVENTORY_KEY.method_1434()) return;
        if (vertical == 0) return;

        OffhandHotbar.scrollInventory(client, vertical > 0);

        ci.cancel();
    }

    @WrapOperation(
            method = "onMouseScroll",
            at = @At(value = "INVOKE", target = "Lnet/minecraft/entity/player/PlayerInventory;setSelectedSlot(I)V")
    )
    private void scrollOffhand(class_1661 instance, int value, Operation<Void> original) {
        if (OffhandHotbarConfig.scrollControls == class_1268.field_5810 ^ OffhandHotbar.CONTROL_OPPOSITE_KEY.method_1434()) {
            OffhandHotbar.selectedOffhandSlot = value;
            OffhandHotbar.updateOffhandSlots(class_310.method_1551());
        } else
            original.call(instance, value);
    }

    @ModifyExpressionValue(
            method = "onMouseScroll",
            at = @At(value = "INVOKE", target = "Lnet/minecraft/entity/player/PlayerInventory;getSelectedSlot()I")
    )
    private int scrollOffhand(int original) {
        return (OffhandHotbarConfig.scrollControls == class_1268.field_5810 ^ OffhandHotbar.CONTROL_OPPOSITE_KEY.method_1434())
                ? OffhandHotbar.selectedOffhandSlot : original;
    }
}

==> offhandhotbar-1.1.0%2Bmc1.21.9-sources.jar: archives/tater/offhandhotbar/mixin/client/MouseMixin.java <==
package archives.tater.offhandhotbar.mixin.client;

import archives.tater.offhandhotbar.OffhandHotbar;
import archives.tater.offhandhotbar.OffhandHotbarConfig;

import com.llamalad7.mixinextras.injector.ModifyExpressionValue;
import com.llamalad7.mixinextras.injector.wrapoperation.Operation;
import com.llamalad7.mixinextras.injector.wrapoperation.WrapOperation;
import net.minecraft.class_1268;
import net.minecraft.class_1661;
import net.minecraft.class_310;
import net.minecraft.class_312;
import org.spongepowered.asm.mixin.Final;
import org.spongepowered.asm.mixin.Mixin;
import org.spongepowered.asm.mixin.Shadow;
import org.spongepowered.asm.mixin.injection.At;
import org.spongepowered.asm.mixin.injection.Inject;
import org.spongepowered.asm.mixin.injection.callback.CallbackInfo;

@Mixin(class_312.class)
public class MouseMixin {
    @Shadow @Final
    private class_310 client;

    @Inject(
            method = "onMouseScroll",
            at = @At(value = "INVOKE", target = "Lnet/minecraft/client/network/ClientPlayerEntity;getInventory()Lnet/minecraft/entity/player/PlayerInventory;"),
            cancellable = true
    )
    private void scrollInventory(long window, double horizontal, double vertical, CallbackInfo ci) {
        if (client.field_1755 != null) return;
        if (!OffhandHotbar.SCROLL_INVENTORY_KEY.method_1434()) return;
        if (vertical == 0) return;

        OffhandHotbar.scrollInventory(client, vertical > 0);

        ci.cancel();
    }

    @WrapOperation(
            method = "onMouseScroll",
            at = @At(value = "INVOKE", target = "Lnet/minecraft/entity/player/PlayerInventory;setSelectedSlot(I)V")
    )
    private void scrollOffhand(class_1661 instance, int value, Operation<Void> original) {
        if (OffhandHotbarConfig.scrollControls == class_1268.field_5810 ^ OffhandHotbar.CONTROL_OPPOSITE_KEY.method_1434()) {
            OffhandHotbar.selectedOffhandSlot = value;
            OffhandHotbar.updateOffhandSlots(client);
            return;
        }
        if (!OffhandHotbar.focusSwapped) {
            original.call(instance, value);
            return;
        }
        OffhandHotbar.updateFocusSwap(client, false);
        original.call(instance, value);
        OffhandHotbar.updateFocusSwap(client, true);
    }

    @ModifyExpressionValue(
            method = "onMouseScroll",
            at = @At(value = "INVOKE", target = "Lnet/minecraft/entity/player/PlayerInventory;getSelectedSlot()I")
    )
    private int scrollOffhand(int original) {
        return (OffhandHotbarConfig.scrollControls == class_1268.field_5810 ^ OffhandHotbar.CONTROL_OPPOSITE_KEY.method_1434())
                ? OffhandHotbar.selectedOffhandSlot : original;
    }
}
